@@ -1,11 +1,11 @@
 library(RcppCWB)
 
-testthat::context("cwb_cpos2rbound")
+testthat::context("cl_cpos2rbound")
 
 test_that(
   "cpos2rbound",
   {
-    cpos <- cwb_cpos2rbound(
+    cpos <- cl_cpos2rbound(
       corpus = "REUTERS",
       s_attribute = "places",
       cpos = 5L,
