@@ -1,11 +1,11 @@
 library(RcppCWB)
 
-testthat::context("cwb_lexicon_size")
+testthat::context("cl_lexicon_size")
 
 test_that(
   "lexicon size",
   {
-    N <- cwb_lexicon_size(
+    N <- cl_lexicon_size(
       corpus = "REUTERS",
       p_attribute = "word",
       registry = system.file(package = "RcppCWB", "extdata", "cwb", "registry")
